#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

# It wasn't packaged, so we ship our own.
UNOCONV="${TESTLIBDIR}/unoconv.py"

check_not_root

# Chosen to be something that the AppArmor profile for LibreOffice
# should normally allow
mkdir -p ~/Documents
docsdir="$(mktemp -d ~/Documents/apertis-tests-libreoffice.XXXXXX)"
cp -a "${MEDIA_RESOURCE_DIR}/documents/"*.od[pst] "${docsdir}/"

setup_success

###########
# Execute #
###########

_to_pdf() {
    if [[ $# -ne 2 ]]; then
        cry "_to_pdf() requires 2 arguments, but $# arguments were passed!"
        return 1
    fi

    "${UNOCONV}" -f pdf --stdout "$1" > "$2" || return 1
    [[ -s "$2" ]] || return 1
    return 0
}

ods_to_pdf() {
    _to_pdf "${docsdir}/"*.ods "${docsdir}/test-$RANDOM.pdf"
}

odp_to_pdf() {
    _to_pdf "${docsdir}/"*.odp "${docsdir}/test-$RANDOM.pdf"
}

odt_to_pdf() {
    _to_pdf "${docsdir}/"*.odt "${docsdir}/test-$RANDOM.pdf"
}

trap "test_failure" ERR

src_test_pass <<-EOF
ods_to_pdf
odp_to_pdf
odt_to_pdf
EOF

rm -fr "${docsdir}"
test_success
